@@ -1,4 +1,4 @@
-# $Id: CheckOS.pm,v 1.30 2008/10/27 20:31:21 drhyde Exp $
+# $Id: CheckOS.pm,v 1.13 2007/10/04 20:15:05 drhyde Exp $
 
 package Devel::CheckOS;
 
@@ -7,7 +7,7 @@ use Exporter;
 
 use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS);
 
-$VERSION = '1.49_01';
+$VERSION = '1.2';
 
 # localising prevents the warningness leaking out of this module
 local $^W = 1;    # use warnings is a 5.6-ism
@@ -32,18 +32,9 @@ like Linux, Solaris, AIX etc.
 
 =head1 SYNOPSIS
 
-    use Devel::CheckOS qw(os_is);
+    use Devel::CheckOS;
     print "Hey, I know this, it's a Unix system\n" if(os_is('Unix'));
 
-    print "You've got Linux 2.6\n" if(os_is('Linux::v2_6'));
-
-=head1 USING IT IN Makefile.PL or Build.PL
-
-If you want to use this from Makefile.PL or Build.PL, do
-not simply copy the module into your distribution as this may cause
-problems when PAUSE and search.cpan.org index the distro.  Instead, use
-the use-devel-assertos script.
-
 =head1 FUNCTIONS
 
 Devel::CheckOS implements the following functions, which load subsidiary
@@ -74,7 +65,7 @@ sub os_is {
     my @targets = @_;
     foreach my $target (@targets) {
         die("Devel::CheckOS: $target isn't a legal OS name\n")
-            unless($target =~ /^\w+(::\w+)*$/);
+            unless($target =~ /^\w+$/);
         eval "use Devel::AssertOS::$target";
         if(!$@) {
             no strict 'refs';
@@ -137,20 +128,11 @@ sub die_unsupported { die("OS unsupported\n"); }
 
 =head3 list_platforms
 
-When called in list context,
-return a list of all the platforms for which the corresponding
+Return a list of all the platforms for which the corresponding
 Devel::AssertOS::* module is available.  This includes both OSes and OS
 families, and both those bundled with this module and any third-party
 add-ons you have installed.
 
-In scalar context, returns a hashref keyed by platform with the filename
-of the most recent version of the supporting module that is available to you.
-This is to make sure that the use-devel-assertos script Does The Right Thing
-in the case where you have installed the module in one version of perl, then
-upgraded perl, and installed it again in the new version.  Sometimes the old
-version of perl and all its modules will still be hanging around and perl
-"helpfully" includes the old perl's search path in its own.
-
 Unfortunately, on some platforms this list may have file case
 broken.  eg, some platforms might return 'freebsd' instead of 'FreeBSD'.
 This is because they have case-insensitive filesystems so things
@@ -158,8 +140,6 @@ should Just Work anyway.
 
 =cut
 
-my ($re_Devel, $re_AssertOS);
-
 sub list_platforms {
     eval " # only load these if needed
         use File::Find::Rule;
@@ -167,44 +147,15 @@ sub list_platforms {
     ";
     
     die($@) if($@);
-    if (!$re_Devel) {
-        my $case_flag = File::Spec->case_tolerant ? '(?i)' : '';
-        $re_Devel    = qr/$case_flag ^Devel$/x;
-        $re_AssertOS = qr/$case_flag ^AssertOS$/x;
-    }
-
-    # sort by mtime, so oldest last
-    my @modules = sort {
-        (stat($a->{file}))[9] <=> (stat($b->{file}))[9]
-    } map {
-        my (undef, $dir_part, $file_part) = File::Spec->splitpath($_);
-        $file_part =~ s/\.pm$//;
-        my (@dirs) = grep {+length} File::Spec->splitdir($dir_part);
-        foreach my $i (reverse 1..$#dirs) {
-            next unless $dirs[$i] =~ $re_AssertOS
-                && $dirs[$i - 1] =~ $re_Devel;
-            splice @dirs, 0, $i + 1;
-            last;
-        }
-        {
-            module => join('::', @dirs, $file_part),
-            file   => File::Spec->canonpath($_)
-        }
+    return sort { $a cmp $b } map {
+        s/^.*\///g;
+        s/\.pm$//gi;
+        $_;
     } File::Find::Rule->file()->name('*.pm')->in(
         grep { -d }
         map { File::Spec->catdir($_, qw(Devel AssertOS)) }
         @INC
     );
-
-    my %modules = map {
-        $_->{module} => $_->{file}
-    } @modules;
-
-    if(wantarray()) {
-        return sort keys %modules;
-    } else {
-        return \%modules;
-    }
 }
 
 =head1 PLATFORMS SUPPORTED
@@ -222,8 +173,15 @@ Sorry.
 
 Also be aware that not all of them have been properly tested.  I don't
 have access to most of them and have had to work from information
-gleaned from L<perlport> and a few other places.  For a complete list of
-OS families, see L<Devel::CheckOS::Families>.
+gleaned from L<perlport> and a few other places.
+
+The following OS 'families' are supported 'out of the box':
+
+    Apple (Mac OS, both classic and OS X)
+    DEC
+    MicrosoftWindows (this matches either MSWin32 or Cygwin)
+    Sun
+    Unix
 
 If you want to add your own OSes or families, see L<Devel::AssertOS::Extending>
 and please feel free to upload the results to the CPAN.
@@ -251,8 +209,6 @@ L<Devel::AssertOS>
 
 L<Devel::AssertOS::Extending>
 
-L<Probe::Perl>
-
 The use-devel-assertos script
 
 =head1 AUTHOR
@@ -268,20 +224,12 @@ information about what should be in the Unix family.
 
 Thanks to Billy Abbott for finding some bugs for me on VMS.
 
-Thanks to Matt Kraai for information about QNX.
-
-Thanks to Kenichi Ishigaki and Gabor Szabo for reporting a bug on Windows,
-and to the former for providing a patch.
-
-=head1 CVS
-
-L<http://drhyde.cvs.sourceforge.net/drhyde/perlmodules/Devel-CheckOS/>
-
 =head1 COPYRIGHT and LICENCE
 
 Copyright 2007 David Cantrell
 
-This software is free-as-in-speech software, and may be used, distributed, and modified under the terms of either the GNU General Public Licence version 2 or the Artistic Licence. It's up to you which one you use. The full text of the licences can be found in the files GPL2.txt and ARTISTIC.txt, respectively.
+This module is free-as-in-speech software, and may be used, distributed,
+and modified under the same conditions as perl itself.
 
 =head1 CONSPIRACY
 
@@ -289,4 +237,4 @@ This module is also free-as-in-mason software.
 
 =cut
 
-1;
+$^O;
